@@ -5,10 +5,6 @@ tests.utils.test_cli_scripts
 
 Test saltfactories.utils.cli_scripts
 """
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import os
 import sys
 import textwrap
